package core.notevault.ui.gallery.detail;

import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.CheckBox;
import android.widget.TextView;
import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;
import core.notevault.R;
import core.notevault.data.MusicNote;

import java.util.ArrayList;
import java.util.List;

public class ConcertSongSelectorAdapter extends RecyclerView.Adapter<ConcertSongSelectorAdapter.ConcertSongSelectorViewHolder> {
    private List<MusicNote> songs;
    private List<MusicNote> selectedSongs = new ArrayList<>();
    private List<MusicNote> filteredSongs;

    public ConcertSongSelectorAdapter(List<MusicNote> songs) {
        this.songs = songs;
        this.filteredSongs = new ArrayList<>(songs);
    }

    @NonNull
    @Override
    public ConcertSongSelectorViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        View view = LayoutInflater.from(parent.getContext())
                .inflate(R.layout.item_concert_song, parent, false);
        return new ConcertSongSelectorViewHolder(view);
    }

    @Override
    public void onBindViewHolder(@NonNull ConcertSongSelectorViewHolder holder, int position) {
        MusicNote song = filteredSongs.get(position);
        holder.bind(song);
    }


    @Override
    public int getItemCount() {
        return filteredSongs.size();
    }

    public List<MusicNote> getSelectedSongs() {
        return selectedSongs;
    }

    public void setSongs(List<MusicNote> musicNotes) {
        songs = musicNotes;
        filteredSongs = new ArrayList<>(musicNotes);
        notifyDataSetChanged();
    }

    public void filter(String query) {
        filteredSongs.clear();
        if (query.isEmpty()) {
            filteredSongs.addAll(songs);
        } else {
            for (MusicNote song : songs) {
                if (song.getTitle().toLowerCase().contains(query.toLowerCase())) {
                    filteredSongs.add(song);
                }
            }
        }
        notifyDataSetChanged();
    }

    class ConcertSongSelectorViewHolder extends RecyclerView.ViewHolder {
        private final TextView songTitle;
        private final CheckBox songCheckbox;

        ConcertSongSelectorViewHolder(View itemView) {
            super(itemView);
            songTitle = itemView.findViewById(R.id.song_title);
            songCheckbox = itemView.findViewById(R.id.song_checkbox);
        }

        void bind(MusicNote song) {
            songTitle.setText(song.getTitle());
            songCheckbox.setChecked(selectedSongs.contains(song));
        }
    }
}
