package core.notevault.ui.gallery.editor;

import android.app.AlertDialog;
import android.app.DatePickerDialog;
import android.app.Dialog;
import android.content.Context;
import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.EditText;
import androidx.annotation.NonNull;
import androidx.fragment.app.DialogFragment;
import core.notevault.R;
import core.notevault.data.Concert;
import core.notevault.ui.metadatadialog.MetaDataDialog;

import java.util.Calendar;
import java.util.Date;

public class ConcertEditorDialog extends DialogFragment {
    private Concert concert;

    private EditText concert_date_input;
    private EditText concertTitleInput;

    private OnConcertEditorListener listener;

    private int concertID = -1;

    public void setConcert(Concert concert) {
        concert_date_input.setText(concert.getConcertDate());
        concertTitleInput.setText(concert.getTitle());
        this.concert = concert;
    }

    public interface OnConcertEditorListener {
        void onConcertEditorClosed(String concertTitle, String concertDate, int concertID);
    }

    public interface OnConcertEditorEditListener {
        void onConcertEditorEditClosed(String concertTitle, String concertDate);
    }

    @NonNull
    @Override
    public Dialog onCreateDialog(Bundle savedInstanceState) {
        LayoutInflater inflater = requireActivity().getLayoutInflater();
        View dialogView = inflater.inflate(R.layout.concert_editor, null);

        EditText title_input = dialogView.findViewById(R.id.concert_title_input);
        concert_date_input = dialogView.findViewById(R.id.concert_date_input);

        concert_date_input.setOnClickListener(v -> showDatePickerDialog());

        if(getArguments() != null) {
            String concertTitle = getArguments().getString("concert_title");
            String concertDate = getArguments().getString("concert_date");
            concertID = getArguments().getInt("concertID");
            title_input.setText(concertTitle);
            concert_date_input.setText(concertDate);

        }

        return new AlertDialog.Builder(requireContext())
                .setView(dialogView)
                .setPositiveButton("Speichern", (dialog, which) -> {
                    String title = title_input.getText().toString();
                    String concertDate = concert_date_input.getText().toString();
                    Log.d("ConcertEditor", "ConcertDate: " + concertDate);

                    listener.onConcertEditorClosed(title, concertDate, concertID);


                })
                .setNegativeButton("Abbrechen", (dialog, which) -> {} )
                .create();
    }

    @Override
    public void onAttach(@NonNull Context context) {
        super.onAttach(context);
        if (context instanceof OnConcertEditorListener) {
            listener = (OnConcertEditorListener) context;
        } else {
            throw new RuntimeException(context.toString()
                    + " must implement OnMetadataListener");
        }
    }

    private void showDatePickerDialog() {
        // Erhalte das aktuelle Datum
        final Calendar calendar = Calendar.getInstance();
        int year = calendar.get(Calendar.YEAR);
        int month = calendar.get(Calendar.MONTH);
        int day = calendar.get(Calendar.DAY_OF_MONTH);

        // Erstelle den DatePickerDialog
        DatePickerDialog datePickerDialog = new DatePickerDialog(this.getContext(),
                (view, selectedYear, selectedMonth, selectedDay) -> {
                    // Setze das ausgewählte Datum in das EditText
                    concert_date_input.setText(selectedDay + "/" + (selectedMonth + 1) + "/" + selectedYear);
                }, year, month, day);

        // Zeige den Dialog an
        datePickerDialog.show();
    }


    public static String TAG = "ConcertEditorDialog";
}
